@@ -24,7 +24,7 @@ if len(sys.argv) == 1:
     sys.argv.append('--help')
 
 parser = argparse.ArgumentParser(description=__description__)
-parser.add_argument('-v', '--version', help="显示版本")
+parser.add_argument('-v', '--version', help="显示版本", action="store_true")
 parser.add_argument('-u', '--url', type=str, help='swagger API接口文档地址（必填)', required=True)
 parser.add_argument('-n', '--username', default=None, type=str, help='swagger用户名')
 parser.add_argument('-w', '--password', default=None, type=str, help='swagger密码')
@@ -38,7 +38,7 @@ def main():
         exit(0)
     arguments = parser.parse_args()
     if not arguments.url:
-        logger.error("Swagger api地址为必填项")
+        logger.error("Swagger API地址为必填项")
     SwaggerParser(arguments.url, arguments.username, arguments.password).gen_testcase(arguments.path)
 
 
